<?php
/**
 * Dolpa Theme Customizer
 *
 * @package Dolpa
 */

/** Sanitize Functions. **/
	require get_template_directory() . '/inc/customizer/default.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if (!function_exists('dolpa_customize_register')) :

function dolpa_customize_register( $wp_customize ) {

	/** Active Callback Functions. **/
	require get_template_directory() . '/inc/customizer/active-callback.php';
	require get_template_directory() . '/inc/customizer/custom-classes.php';
	require get_template_directory() . '/inc/customizer/sanitize.php';
	require get_template_directory() . '/inc/customizer/layout.php';
	require get_template_directory() . '/inc/customizer/preloader.php';
	require get_template_directory() . '/inc/customizer/navigation-settings.php';
	require get_template_directory() . '/inc/customizer/header.php';
	require get_template_directory() . '/inc/customizer/template-settings.php';
	require get_template_directory() . '/inc/customizer/pagination.php';
	require get_template_directory() . '/inc/customizer/post.php';
	require get_template_directory() . '/inc/customizer/single.php';
	require get_template_directory() . '/inc/customizer/footer.php';
	require get_template_directory() . '/inc/customizer/color-schema.php';
	require get_template_directory() . '/inc/customizer/cat-color.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_section( 'colors' )->panel = 'theme_colors_panel';
	$wp_customize->get_section( 'colors' )->title = esc_html__('Color Options','dolpa');
	$wp_customize->get_section( 'title_tagline' )->panel = 'theme_general_settings';
	$wp_customize->get_section( 'header_image' )->panel = 'theme_general_settings';
	$wp_customize->get_section( 'background_image' )->panel = 'theme_general_settings';

	$dolpa_default = dolpa_get_default_theme_options();
	
	$wp_customize->add_setting('ed_site_title',
	    array(
	        'default' => $dolpa_default['ed_site_title'],
	        'capability' => 'edit_theme_options',
	        'sanitize_callback' => 'dolpa_sanitize_checkbox',
	    )
	);

	$wp_customize->add_control('ed_site_title',
	    array(
	        'label' => esc_html__('Display Site Title and Tagline', 'dolpa'),
	        'section' => 'title_tagline',
	        'type' => 'checkbox',
	    )
	);


	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'dolpa_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'dolpa_customize_partial_blogdescription',
		) );
	}

	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_option_panel',
		array(
			'title'      => esc_html__( 'Theme Options', 'dolpa' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_general_settings',
		array(
			'title'      => esc_html__( 'General Settings', 'dolpa' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_colors_panel',
		array(
			'title'      => esc_html__( 'Color Settings', 'dolpa' ),
			'priority'   => 15,
			'capability' => 'edit_theme_options',
		)
	);
	
	// Template Options
	$wp_customize->add_panel( 'theme_template_pannel',
		array(
			'title'      => esc_html__( 'Template Settings', 'dolpa' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);

	// Register custom section types.
	$wp_customize->register_section_type( 'Dolpa_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Dolpa_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Dolpa Pro', 'dolpa' ),
				'pro_text' => esc_html__( 'Upgrade To Pro', 'dolpa' ),
				'pro_url'  => esc_url('https://www.themeinwp.com/theme/dolpa-pro/'),
				'priority'  => 1,
			)
		)
	);

}

endif;
add_action( 'customize_register', 'dolpa_customize_register' );

/**
 * Customizer Enqueue scripts and styles.
 */

if (!function_exists('dolpa_customizer_scripts')) :

    function dolpa_customizer_scripts(){   
    	
    	wp_enqueue_script('jquery-ui-button');
    	wp_enqueue_style('dolpa-repeater', get_template_directory_uri() . '/assets/lib/custom/css/repeater.css');
    	wp_enqueue_style('dolpa-customizer', get_template_directory_uri() . '/assets/lib/custom/css/customizer.css');
        wp_enqueue_script('dolpa-customizer', get_template_directory_uri() . '/assets/lib/custom/js/customizer.js', array('jquery','customize-controls'), '', 1);
        wp_enqueue_script('dolpa-repeater', get_template_directory_uri() . '/assets/lib/custom/js/repeater.js', array('jquery','customize-controls'), '', 1);

	    $dolpa_post_category_list = dolpa_post_category_list();

	    $cat_option = '';

	    if( $dolpa_post_category_list ){
		    foreach( $dolpa_post_category_list as $key => $cats ){
		    	$cat_option .= "<option value='". esc_attr( $key )."'>". esc_html( $cats )."</option>";
		    }
		}

	    wp_localize_script( 
	        'dolpa-repeater', 
	        'dolpa_repeater',
	        array(
	           	'categories'   => $cat_option,
	            'upload_image'   =>  esc_html__('Choose Image','dolpa'),
	            'use_imahe'   =>  esc_html__('Select','dolpa'),
	         )
	    );
        $ajax_nonce = wp_create_nonce('dolpa_ajax_nonce');
        wp_localize_script( 
		    'dolpa-customizer', 
		    'dolpa_customizer',
		    array(
		        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
		        'ajax_nonce' => $ajax_nonce,
		     )
		);
    }

endif;

add_action('customize_controls_enqueue_scripts', 'dolpa_customizer_scripts');
add_action('customize_controls_init', 'dolpa_customizer_scripts');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('dolpa_customize_partial_blogname')) :

	function dolpa_customize_partial_blogname() {
		bloginfo( 'name' );
	}
endif;

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('dolpa_customize_partial_blogdescription')) :

	function dolpa_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}

endif;


add_action('wp_ajax_dolpa_customizer_font_weight', 'dolpa_customizer_font_weight_callback');
add_action('wp_ajax_nopriv_dolpa_customizer_font_weight', 'dolpa_customizer_font_weight_callback');

// Recommendec Post Ajax Call Function.
function dolpa_customizer_font_weight_callback() {

    if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce( $_POST['_wpnonce'], 'dolpa_ajax_nonce' ) && isset( $_POST['currentfont'] ) && $_POST['currentfont']  ) {

       $currentfont = $_POST['currentfont'];
       $headings_fonts_property = Dolpa_Fonts::dolpa_get_fonts_property( $currentfont );

       foreach( $headings_fonts_property['weight'] as $key => $value ){
       		echo '<option value="'.esc_attr( $key ).'">'.esc_html( $value ).'</option>';
       }
    }
    wp_die();
}

if (!function_exists('dolpa_color_schema_color')):

    function dolpa_color_schema_color($current_color)
    {
        $dolpa_default = dolpa_get_default_theme_options();
        $colors_schema = array(
            'default' => array(
                'background_color' => $dolpa_default['default_bg_color'],
            ),
            'fancy' => array(
                'background_color' => $dolpa_default['fancy_bg_color'],
            ),
            'dark' => array(
                'background_color' => $dolpa_default['dark_bg_color'],
            ),
            'shady' => array(
                'background_color' => $dolpa_default['shady_bg_color'],
            ),
        );
        if (isset($colors_schema[$current_color])) {
            return $colors_schema[$current_color];
        }
        return;
    }

endif;

if (!function_exists('dolpa_color_schema_color_action')) :

    function dolpa_color_schema_color_action()
    {
        if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce(  sanitize_text_field( wp_unslash( $_POST['_wpnonce'] ) ), 'dolpa_ajax_nonce' ) && isset( $_POST['currentColor'] ) ) {

            $current_color = sanitize_text_field( wp_unslash( $_POST['currentColor'] ) );
            $color_schemes = dolpa_color_schema_color( $current_color );

            if ($color_schemes) {

                echo json_encode($color_schemes);
            }
        }

        wp_die();
    }
endif;

add_action('wp_ajax_nopriv_dolpa_color_schema_color', 'dolpa_color_schema_color_action');
add_action('wp_ajax_dolpa_color_schema_color', 'dolpa_color_schema_color_action');